Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-10-05 03:27:04 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-10-05 03:29:31 +0300
commit0b98a679bb799fe496be67d8dd52fadef3c1027a (patch)
tree83302b41f2481cf9aad168459dce08a971b9d0fb /source/blender/editors/space_clip
parent50cb8013ebf8e421a16428756dd869ab844b41f6 (diff)
UI: rename Border Select -> Box Select
See: T56648
Diffstat (limited to 'source/blender/editors/space_clip')
-rw-r--r--source/blender/editors/space_clip/clip_graph_ops.c32
-rw-r--r--source/blender/editors/space_clip/clip_intern.h4
-rw-r--r--source/blender/editors/space_clip/space_clip.c8
-rw-r--r--source/blender/editors/space_clip/tracking_select.c20
4 files changed, 32 insertions, 32 deletions
diff --git a/source/blender/editors/space_clip/clip_intern.h b/source/blender/editors/space_clip/clip_intern.h
index e5c4f567d5c..b407056ea96 100644
--- a/source/blender/editors/space_clip/clip_intern.h
+++ b/source/blender/editors/space_clip/clip_intern.h
@@ -84,7 +84,7 @@ void clip_draw_graph(struct SpaceClip *sc, struct ARegion *ar, struct Scene *sce
void ED_clip_graph_center_current_frame(struct Scene *scene, struct ARegion *ar);
void CLIP_OT_graph_select(struct wmOperatorType *ot);
-void CLIP_OT_graph_select_border(struct wmOperatorType *ot);
+void CLIP_OT_graph_select_box(struct wmOperatorType *ot);
void CLIP_OT_graph_select_all_markers(struct wmOperatorType *ot);
void CLIP_OT_graph_delete_curve(struct wmOperatorType *ot);
void CLIP_OT_graph_delete_knot(struct wmOperatorType *ot);
@@ -212,7 +212,7 @@ void CLIP_OT_keyframe_delete(struct wmOperatorType *ot);
/* tracking_select.c */
void CLIP_OT_select(struct wmOperatorType *ot);
void CLIP_OT_select_all(struct wmOperatorType *ot);
-void CLIP_OT_select_border(struct wmOperatorType *ot);
+void CLIP_OT_select_box(struct wmOperatorType *ot);
void CLIP_OT_select_lasso(struct wmOperatorType *ot);
void CLIP_OT_select_circle(struct wmOperatorType *ot);
void CLIP_OT_select_grouped(struct wmOperatorType *ot);
diff --git a/source/blender/editors/space_clip/space_clip.c b/source/blender/editors/space_clip/space_clip.c
index f38a1dc056a..8afc0c33271 100644
--- a/source/blender/editors/space_clip/space_clip.c
+++ b/source/blender/editors/space_clip/space_clip.c
@@ -447,7 +447,7 @@ static void clip_operatortypes(void)
/* selection */
WM_operatortype_append(CLIP_OT_select);
WM_operatortype_append(CLIP_OT_select_all);
- WM_operatortype_append(CLIP_OT_select_border);
+ WM_operatortype_append(CLIP_OT_select_box);
WM_operatortype_append(CLIP_OT_select_lasso);
WM_operatortype_append(CLIP_OT_select_circle);
WM_operatortype_append(CLIP_OT_select_grouped);
@@ -521,7 +521,7 @@ static void clip_operatortypes(void)
/* selection */
WM_operatortype_append(CLIP_OT_graph_select);
- WM_operatortype_append(CLIP_OT_graph_select_border);
+ WM_operatortype_append(CLIP_OT_graph_select_box);
WM_operatortype_append(CLIP_OT_graph_select_all_markers);
WM_operatortype_append(CLIP_OT_graph_delete_curve);
@@ -649,7 +649,7 @@ static void clip_keymap(struct wmKeyConfig *keyconf)
ED_keymap_template_select_all(keymap, "CLIP_OT_select_all");
- WM_keymap_add_item(keymap, "CLIP_OT_select_border", BKEY, KM_PRESS, 0, 0);
+ WM_keymap_add_item(keymap, "CLIP_OT_select_box", BKEY, KM_PRESS, 0, 0);
WM_keymap_add_item(keymap, "CLIP_OT_select_circle", CKEY, KM_PRESS, 0, 0);
WM_keymap_add_menu(keymap, "CLIP_MT_select_grouped", GKEY, KM_PRESS, KM_SHIFT, 0);
@@ -750,7 +750,7 @@ static void clip_keymap(struct wmKeyConfig *keyconf)
ED_keymap_template_select_all(keymap, "CLIP_OT_graph_select_all_markers");
- WM_keymap_add_item(keymap, "CLIP_OT_graph_select_border", BKEY, KM_PRESS, 0, 0);
+ WM_keymap_add_item(keymap, "CLIP_OT_graph_select_box", BKEY, KM_PRESS, 0, 0);
/* delete */
WM_keymap_add_item(keymap, "CLIP_OT_graph_delete_curve", XKEY, KM_PRESS, 0, 0);
diff --git a/source/blender/editors/space_clip/clip_graph_ops.c b/source/blender/editors/space_clip/clip_graph_ops.c
index 5b51f70c447..06233d64a36 100644
--- a/source/blender/editors/space_clip/clip_graph_ops.c
+++ b/source/blender/editors/space_clip/clip_graph_ops.c
@@ -329,17 +329,17 @@ void CLIP_OT_graph_select(wmOperatorType *ot)
"Extend", "Extend selection rather than clearing the existing selection");
}
-/********************** border select operator *********************/
+/********************** box select operator *********************/
-typedef struct BorderSelectuserData {
+typedef struct BoxSelectuserData {
rctf rect;
bool select, extend, changed;
-} BorderSelectuserData;
+} BoxSelectuserData;
-static void border_select_cb(void *userdata, MovieTrackingTrack *UNUSED(track),
+static void box_select_cb(void *userdata, MovieTrackingTrack *UNUSED(track),
MovieTrackingMarker *marker, int coord, int scene_framenr, float val)
{
- BorderSelectuserData *data = (BorderSelectuserData *) userdata;
+ BoxSelectuserData *data = (BoxSelectuserData *) userdata;
if (BLI_rctf_isect_pt(&data->rect, scene_framenr, val)) {
int flag = 0;
@@ -362,7 +362,7 @@ static void border_select_cb(void *userdata, MovieTrackingTrack *UNUSED(track),
}
}
-static int border_select_graph_exec(bContext *C, wmOperator *op)
+static int box_select_graph_exec(bContext *C, wmOperator *op)
{
SpaceClip *sc = CTX_wm_space_clip(C);
ARegion *ar = CTX_wm_region(C);
@@ -370,7 +370,7 @@ static int border_select_graph_exec(bContext *C, wmOperator *op)
MovieClip *clip = ED_space_clip_get_clip(sc);
MovieTracking *tracking = &clip->tracking;
MovieTrackingTrack *act_track = BKE_tracking_track_get_active(tracking);
- BorderSelectuserData userdata;
+ BoxSelectuserData userdata;
rctf rect;
if (act_track == NULL) {
@@ -385,7 +385,7 @@ static int border_select_graph_exec(bContext *C, wmOperator *op)
userdata.select = !RNA_boolean_get(op->ptr, "deselect");
userdata.extend = RNA_boolean_get(op->ptr, "extend");
- clip_graph_tracking_values_iterate_track(sc, act_track, &userdata, border_select_cb, NULL, NULL);
+ clip_graph_tracking_values_iterate_track(sc, act_track, &userdata, box_select_cb, NULL, NULL);
if (userdata.changed) {
WM_event_add_notifier(C, NC_GEOM | ND_SELECT, NULL);
@@ -396,24 +396,24 @@ static int border_select_graph_exec(bContext *C, wmOperator *op)
return OPERATOR_CANCELLED;
}
-void CLIP_OT_graph_select_border(wmOperatorType *ot)
+void CLIP_OT_graph_select_box(wmOperatorType *ot)
{
/* identifiers */
- ot->name = "Border Select";
- ot->description = "Select curve points using border selection";
- ot->idname = "CLIP_OT_graph_select_border";
+ ot->name = "Box Select";
+ ot->description = "Select curve points using box selection";
+ ot->idname = "CLIP_OT_graph_select_box";
/* api callbacks */
- ot->invoke = WM_gesture_border_invoke;
- ot->exec = border_select_graph_exec;
- ot->modal = WM_gesture_border_modal;
+ ot->invoke = WM_gesture_box_invoke;
+ ot->exec = box_select_graph_exec;
+ ot->modal = WM_gesture_box_modal;
ot->poll = clip_graph_knots_poll;
/* flags */
ot->flag = OPTYPE_UNDO;
/* properties */
- WM_operator_properties_gesture_border_select(ot);
+ WM_operator_properties_gesture_box_select(ot);
}
/********************** select all operator *********************/
diff --git a/source/blender/editors/space_clip/tracking_select.c b/source/blender/editors/space_clip/tracking_select.c
index 7fb2e32770d..162948c8e64 100644
--- a/source/blender/editors/space_clip/tracking_select.c
+++ b/source/blender/editors/space_clip/tracking_select.c
@@ -427,9 +427,9 @@ void CLIP_OT_select(wmOperatorType *ot)
"Location", "Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds", -100.0f, 100.0f);
}
-/********************** border select operator *********************/
+/********************** box select operator *********************/
-static int border_select_exec(bContext *C, wmOperator *op)
+static int box_select_exec(bContext *C, wmOperator *op)
{
SpaceClip *sc = CTX_wm_space_clip(C);
ARegion *ar = CTX_wm_region(C);
@@ -519,24 +519,24 @@ static int border_select_exec(bContext *C, wmOperator *op)
return OPERATOR_CANCELLED;
}
-void CLIP_OT_select_border(wmOperatorType *ot)
+void CLIP_OT_select_box(wmOperatorType *ot)
{
/* identifiers */
- ot->name = "Border Select";
- ot->description = "Select markers using border selection";
- ot->idname = "CLIP_OT_select_border";
+ ot->name = "Box Select";
+ ot->description = "Select markers using box selection";
+ ot->idname = "CLIP_OT_select_box";
/* api callbacks */
- ot->invoke = WM_gesture_border_invoke;
- ot->exec = border_select_exec;
- ot->modal = WM_gesture_border_modal;
+ ot->invoke = WM_gesture_box_invoke;
+ ot->exec = box_select_exec;
+ ot->modal = WM_gesture_box_modal;
ot->poll = ED_space_clip_tracking_poll;
/* flags */
ot->flag = OPTYPE_UNDO;
/* properties */
- WM_operator_properties_gesture_border_select(ot);
+ WM_operator_properties_gesture_box_select(ot);
}
/********************** lasso select operator *********************/